==> ckan-metadata-publisher-widget-2.5.0-20250922.154604-3-servicearchive.tar.gz: README.md <==
# gCube Catalogue Metadata Publisher Widget

gCube Ckan metadata publisher widget is a GWT Widget that allows to publish metadata on the D4science Data Catalogue powered by CKAN.

## Built With

* [OpenJDK](https://openjdk.java.net/) - The JDK used
* [Maven](https://maven.apache.org/) - Dependency Management

## Documentation

You can find the D4Science Catalogue documentation at [GCat Background Wiki Page](https://wiki.gcube-system.org/GCat_Background)

## Change log

See the [Releases](https://code-repo.d4science.org/gCubeSystem/ckan-metadata-publisher-widget/releases)

## Authors

* **Francesco Mangiacrapa** ([ORCID](https://orcid.org/0000-0002-6528-664X)) Computer Scientist at [ISTI-CNR Infrascience Group](https://infrascience.isti.cnr.it/)
* **Costantino Perciante**

## How to Cite this Software

Tell people how to cite this software.

* Cite an associated paper?
* Use a specific BibTeX entry for the software?

```Latex
    @Manual{,
        title = {gCube Catalogue Metadata Publisher Widget},
        author = {Francesco Mangiacrapa at ISTI-CNR Infrascience Group},
        organization = {ISTI - CNR},
        address = {Pisa, Italy},
        year = 2025,
        note = {gCube Ckan metadata publisher widget allows to publish metadata on the D4science Data Catalogue powered by CKAN},
        url = {http://www.http://gcube-system.org/}
    } 
```

## License

This project is licensed under the license **EUPL V. 1.2** - see the [LICENSE.md](LICENSE.md) file for details.


## About the gCube Framework

This software is part of the [gCubeFramework](https://www.gcube-system.org/gCubeFramework): an
open-source software toolkit used for building and operating Hybrid Data
Infrastructures enabling the dynamic deployment of Virtual Research Environments
by favouring the realisation of reuse oriented policies.

The projects leading to this software have received funding from a series of European Union programmes see [FUNDING.md](FUNDING.md)

==> ckan-metadata-publisher-widget-2.5.0-20251009.151217-5-servicearchive.tar.gz: README.md <==
# gCube Catalogue Metadata Publisher Widget

gCube Ckan metadata publisher widget is a GWT Widget that allows to publish metadata on the D4science Data Catalogue powered by CKAN.

## Built With

* [OpenJDK](https://openjdk.java.net/) - The JDK used
* [Maven](https://maven.apache.org/) - Dependency Management

## Documentation

You can find the D4Science Catalogue documentation at [GCat Background Wiki Page](https://wiki.gcube-system.org/GCat_Background)

## Change log

See the [Releases](https://code-repo.d4science.org/gCubeSystem/ckan-metadata-publisher-widget/releases)

## Authors

* **Francesco Mangiacrapa** ([ORCID](https://orcid.org/0000-0002-6528-664X)) Computer Scientist at [ISTI-CNR Infrascience Group](https://infrascience.isti.cnr.it/)
* **Costantino Perciante**

## How to Cite this Software

Tell people how to cite this software.

* Cite an associated paper?
* Use a specific BibTeX entry for the software?

```Latex
    @Manual{,
        title = {gCube Catalogue Metadata Publisher Widget},
        author = {Francesco Mangiacrapa at ISTI-CNR Infrascience Group},
        organization = {ISTI - CNR},
        address = {Pisa, Italy},
        year = 2025,
        note = {gCube Ckan metadata publisher widget allows to publish metadata on the D4science Data Catalogue powered by CKAN},
        url = {http://www.http://gcube-system.org/}
    } 
```

* More information in [CITATION.cff](CITATION.cff) 

## License

This project is licensed under the terms specified in the [LICENSE.md](LICENSE.md) file


## About the gCube Framework

This software is part of the [gCubeFramework](https://www.gcube-system.org/): an
open-source software toolkit used for building and operating Hybrid Data
Infrastructures enabling the dynamic deployment of Virtual Research Environments
by favouring the realisation of reuse oriented policies.

The projects leading to this software have received funding from a series of European Union programmes see [FUNDING.md](FUNDING.md)
